@@ -163,6 +163,20 @@ class RKAdmin(RKClient):
 
         return _handle_request(_get_tags, "Getting tags")
 
+    def get_tags_count(self) -> Tuple[int, str, bool]:
+        """
+        Returns amount of tags.
+        """
+
+        def _get_tags() -> Tuple[int, str, bool]:
+            text, ok = self._get("/tags_count")
+            if not ok:
+                return -1, text, False
+            obj = json.loads(text)
+            return int(obj['tags_count']), 'OK', True
+
+        return _handle_request(_get_tags, "Getting tags count")
+
     def query_graph(self, query: str, query_type='rw') -> Tuple[str, bool]:
         """
         :return: first element: returned result (as str with format corresponding to what query requests) or error message
