@@ -18,6 +18,8 @@ MOCK_ENV_VAR = "RK_MOCK"
 class RKClientMock(RKClient):
     def __init__(self, receiver_url: str, emitter_id: Optional[UUID] = None, timeout_sec: int = 5, user_auth: str = ''): # noqa
         log.info(f"ver {RK_VERSION} - using MOCK client")
+        if emitter_id is None:
+            emitter_id = uuid1()
         self.emitter_id = emitter_id
 
     def __enter__(self):
